@@ -1,6 +1,7 @@
 """Update DNS data for dynamic ip addresses."""
 
 import argparse
+import ast
 import configparser
 import glob
 import importlib
@@ -13,7 +14,6 @@ import os.path
 import stat
 import sys
 import time
-import ast
 
 
 from ddupdate.ddplugin import AddressPlugin, AddressError
@@ -63,7 +63,8 @@ def ip_cache_setup(opts):
     """Ensure that our cache directory exists, return cache file path."""
     if not os.path.exists(opts.ip_cache):
         os.makedirs(opts.ip_cache)
-    return os.path.join(opts.ip_cache, opts.service_plugin + '.ip')
+    return os.path.join(opts.ip_cache, opts.service_plugin + '_' +
+                                       opts.hostname + '.ip')
 
 
 def ip_cache_clear(opts, log):
@@ -130,7 +131,8 @@ def parse_conffile(log):
                 # Trust that the regular parsing handles the error.
                 return None
     if not os.access(path, os.R_OK):
-        log.warning("Cannot open config file '%s' for read", path)
+        log.warning("Cannot open config file ~/.config/ddupdate.conf for read",
+                path)
         return None
     return path
 
@@ -261,7 +263,7 @@ def parse_options(conf):
         'debug': logging.DEBUG,
     }
     parser = get_parser(conf)
-    parser.version = "0.7.1"
+    parser.version = "0.7.2"
     opts = parser.parse_args()
     if opts.help == '-':
         parser.print_help()
